@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
-'''
+"""
 
-  canteen: RPC protocol
-  ~~~~~~~~~~~~~~~~~~~~~
+  RPC protocol
+  ~~~~~~~~~~~~
 
   :author: Sam Gammon <sg@samgammon.com>
   :copyright: (c) Sam Gammon, 2014
@@ -11,12 +11,12 @@
             A copy of this license is included as ``LICENSE.md`` in
             the root of the project.
 
-'''
+"""
 
 # submodules
-from . import jsonrpc
+from . import json
+from . import msgpack
 
 
-__all__ = (
-  'jsonrpc',
-)
+__all__ = ('json',
+           'msgpack')
