@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
-'''
+"""
 
-  canteen: debug utils
-  ~~~~~~~~~~~~~~~~~~~~
+  debug utils
+  ~~~~~~~~~~~
 
   :author: Sam Gammon <sg@samgammon.com>
   :copyright: (c) Sam Gammon, 2014
@@ -11,26 +11,24 @@
             A copy of this license is included as ``LICENSE.md`` in
             the root of the project.
 
-'''
+"""
 
 # stdlib
 import sys
 
 # 3rd party / stdlib
 try:
+  # noinspection PyPackageRequirements
   import logbook as logging
 except ImportError:
   import logging
   logging.basicConfig(stream=sys.stdout, level=10, format='%(message)s')
 
 
-def Logger(name):
+def Logger(name):  # pragma: no cover
 
-  '''  '''
+  """  """
 
   logger = logging.getLogger(name)
   logger.setLevel(10)
   return logger
-
-
-__all__ = ('Logger',)
